@@ -10,7 +10,7 @@ import sys
 from scipy.spatial.distance import cdist, pdist
 from matplotlib import rcParams
 import matplotlib.pyplot as plt
-
+from plotnine import *
 
 def ReadPDBintoDataFrame(PDBfileNameString):
     DataFrame = pandas.DataFrame(PandasPdb().read_pdb(PDBfileNameString).df["ATOM"])
@@ -30,8 +30,15 @@ def GetSegmentIDs(PDBDataFrame):
     SegmentSet = PDBDataFrame.segment_id.unique()
     return SegmentSet
 def EuclideanDistance(coords1, coords2):
+    if type(coords1) and type(coords2) is list:
+        coords1 = numpy.array(coords1)
+        coords2 = numpy.array(coords2)
+    if type(coords1) and type(coords2) is tuple:
+        coords1 = numpy.array(list(coords1))
+        coords2 = numpy.array(list(coords2))
     return numpy.linalg.norm(coords1-coords2)
 
+
 protein_letters = "ACDEFGHIKLMNPQRSTVWY"
 extended_protein_letters = "ACDEFGHIKLMNPQRSTVWYBXZJUO"
 protein_letters_1to3 = {
@@ -290,7 +297,7 @@ def DoubleClickButton(FileName):
 def DoubleClick(FileName):
     os.system(FileName)
 
-def RamachandranPlot(TorsionAngleDataFrame, ResidueRange = 1, ChainIDsToExclude = [], Name = ''):
+def RamachandranPlot(TorsionAngleDataFrame, ResidueRange = 1, ChainIDsToExclude = [], Name = '', ColorColumn = None, Colors = None):
     if type(ResidueRange) is int :
         ResidueStart = ResidueRange
         ResidueStop = TorsionAngleDataFrame["Residue Number"].max()
@@ -303,20 +310,38 @@ def RamachandranPlot(TorsionAngleDataFrame, ResidueRange = 1, ChainIDsToExclude
     residues = list(numpy.linspace(ResidueStart, ResidueStop, dtype=numpy.integer))
     TorsionAngleDataFrame = TorsionAngleDataFrame[TorsionAngleDataFrame["Residue Number"].isin(residues)]
     TorsionAngleDataFrame = TorsionAngleDataFrame[~TorsionAngleDataFrame["Chain ID"].isin(ChainIDsToExclude)]
-    rcParams.update({'text.usetex': False, "svg.fonttype": 'none' })
-    ticks = numpy.arange(-180, 181, 30)
-    plt.xlim([-180, 180])
-    plt.ylim([-180, 180])
-    plt.xlabel('phi')
-    plt.ylabel('psi')
-    plt.xticks(ticks)
-    plt.yticks(ticks)
-    plt.grid()
+    plot = (ggplot(aes(x='Phi', y='Psi'), data=TorsionAngleDataFrame) 
+     + geom_point(colour = "blue", alpha = .5)
+     + scale_x_continuous(
+            limits = (-180, 180),
+            labels = (-180, -150, -120, -90, -60, -30, 0, 30, 60, 90, 120, 150, 180),
+            breaks = (-180, -150, -120, -90, -60, -30, 0, 30, 60, 90, 120, 150, 180))
+     + scale_y_continuous(
+            limits = (-180, 180),
+            labels = (-180, -150, -120, -90, -60, -30, 0, 30, 60, 90, 120, 150, 180),
+            breaks = (-180, -150, -120, -90, -60, -30, 0, 30, 60, 90, 120, 150, 180))
+     + theme_bw()
+    )
     if ResidueStart == ResidueStop:
-        plt.title(Name + " Torsion Angles for Residue " + str(ResidueStart))
+        plot += ggtitle(Name + " Torsion Angles for Residue " + str(ResidueStart))
     else:
-        plt.title(Name + " Torsion Angles from Residues " + str(ResidueStart) + " to " + str(ResidueStop))
-    plt.scatter(TorsionAngleDataFrame.Phi, TorsionAngleDataFrame.Psi, alpha=0.5)
+        plot += ggtitle(Name + " Torsion Angles for Residues " + str(ResidueStart) + " to " + str(ResidueStop))
+    if ColorColumn != None:
+        plot += aes(color = ColorColumn)
+        plot += geom_point()
+    if Colors != None:
+        plot += scale_color_manual(values=Colors)
+    return plot
+def SavePlot(Plot, FileName):
+    ggsave(Plot, FileName)
+def DisplayPlot(Plot):
+    Plot.draw()
+def ResizePlot(Plot, Dimension1, Dimension2):
+    Plot += theme(figure_size = (Dimension1, Dimension2))
+    return Plot
+def SavePlot(Plot, FileName):
+    rcParams.update({'text.usetex': False, "svg.fonttype": 'none' })
+    ggsave(Plot, FileName)
 def FindPotentialClashes(PDBDataFrame, Atom1Name, Atom2Name, DistanceLimit):
     PDBDataFrame["atom_name"] = PDBDataFrame.atom_name.str.slice(stop=1)
     Atom1Array = PDBDataFrame.loc[PDBDataFrame["atom_name"] == Atom1Name][["x_coord", "y_coord", "z_coord"]]
